@@ -155,9 +155,15 @@ class H2ODRFParams(HasCalibrationDataFrame, HasIgnoredCols, Params):
     calibrateModel = Param(
         Params._dummy(),
         "calibrateModel",
-        """Use Platt Scaling to calculate calibrated class probabilities. Calibration can provide more accurate estimates of class probabilities.""",
+        """Use Platt Scaling (default) or Isotonic Regression to calculate calibrated class probabilities. Calibration can provide more accurate estimates of class probabilities.""",
         H2OTypeConverters.toBoolean())
 
+    calibrationMethod = Param(
+        Params._dummy(),
+        "calibrationMethod",
+        """Calibration method to use""",
+        H2OTypeConverters.toEnumString("hex.tree.CalibrationHelper$CalibrationMethod"))
+
     checkConstantResponse = Param(
         Params._dummy(),
         "checkConstantResponse",
@@ -209,7 +215,7 @@ class H2ODRFParams(HasCalibrationDataFrame, HasIgnoredCols, Params):
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -290,6 +296,12 @@ class H2ODRFParams(HasCalibrationDataFrame, HasIgnoredCols, Params):
         """Automatically export generated models to this directory.""",
         H2OTypeConverters.toNullableString())
 
+    aucType = Param(
+        Params._dummy(),
+        "aucType",
+        """Set default multinomial AUC type.""",
+        H2OTypeConverters.toEnumString("hex.MultinomialAucType"))
+
     ##
     # Getters
     ##
@@ -359,6 +371,9 @@ class H2ODRFParams(HasCalibrationDataFrame, HasIgnoredCols, Params):
     def getCalibrateModel(self):
         return self.getOrDefault(self.calibrateModel)
 
+    def getCalibrationMethod(self):
+        return self.getOrDefault(self.calibrationMethod)
+
     def getCheckConstantResponse(self):
         return self.getOrDefault(self.checkConstantResponse)
 
@@ -425,6 +440,9 @@ class H2ODRFParams(HasCalibrationDataFrame, HasIgnoredCols, Params):
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
+    def getAucType(self):
+        return self.getOrDefault(self.aucType)
+
     ##
     # Setters
     ##
@@ -494,6 +512,9 @@ class H2ODRFParams(HasCalibrationDataFrame, HasIgnoredCols, Params):
     def setCalibrateModel(self, value):
         return self._set(calibrateModel=value)
 
+    def setCalibrationMethod(self, value):
+        return self._set(calibrationMethod=value)
+
     def setCheckConstantResponse(self, value):
         return self._set(checkConstantResponse=value)
 
@@ -559,3 +580,6 @@ class H2ODRFParams(HasCalibrationDataFrame, HasIgnoredCols, Params):
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
+
+    def setAucType(self, value):
+        return self._set(aucType=value)
