@@ -63,6 +63,12 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
         """Bandwidth (sigma) of Gaussian multiplicative noise ~N(1,sigma) for tree node predictions""",
         H2OTypeConverters.toFloat())
 
+    interactionConstraints = Param(
+        Params._dummy(),
+        "interactionConstraints",
+        """A set of allowed column interactions.""",
+        H2OTypeConverters.toNullableListListString())
+
     balanceClasses = Param(
         Params._dummy(),
         "balanceClasses",
@@ -174,15 +180,33 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
     calibrateModel = Param(
         Params._dummy(),
         "calibrateModel",
-        """Use Platt Scaling to calculate calibrated class probabilities. Calibration can provide more accurate estimates of class probabilities.""",
+        """Use Platt Scaling (default) or Isotonic Regression to calculate calibrated class probabilities. Calibration can provide more accurate estimates of class probabilities.""",
         H2OTypeConverters.toBoolean())
 
+    calibrationMethod = Param(
+        Params._dummy(),
+        "calibrationMethod",
+        """Calibration method to use""",
+        H2OTypeConverters.toEnumString("hex.tree.CalibrationHelper$CalibrationMethod"))
+
     checkConstantResponse = Param(
         Params._dummy(),
         "checkConstantResponse",
         """Check if response column is constant. If enabled, then an exception is thrown if the response column is a constant value.If disabled, then model will train regardless of the response column being a constant value or not.""",
         H2OTypeConverters.toBoolean())
 
+    inTrainingCheckpointsDir = Param(
+        Params._dummy(),
+        "inTrainingCheckpointsDir",
+        """Create checkpoints into defined directory while training process is still running. In case of cluster shutdown, this checkpoint can be used to restart training.""",
+        H2OTypeConverters.toNullableString())
+
+    inTrainingCheckpointsTreeInterval = Param(
+        Params._dummy(),
+        "inTrainingCheckpointsTreeInterval",
+        """Checkpoint the model after every so many trees. Parameter is used only when in_training_checkpoints_dir is defined""",
+        H2OTypeConverters.toInt())
+
     modelId = Param(
         Params._dummy(),
         "modelId",
@@ -360,6 +384,9 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
     def getPredNoiseBandwidth(self):
         return self.getOrDefault(self.predNoiseBandwidth)
 
+    def getInteractionConstraints(self):
+        return self.getOrDefault(self.interactionConstraints)
+
     def getBalanceClasses(self):
         return self.getOrDefault(self.balanceClasses)
 
@@ -417,9 +444,18 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
     def getCalibrateModel(self):
         return self.getOrDefault(self.calibrateModel)
 
+    def getCalibrationMethod(self):
+        return self.getOrDefault(self.calibrationMethod)
+
     def getCheckConstantResponse(self):
         return self.getOrDefault(self.checkConstantResponse)
 
+    def getInTrainingCheckpointsDir(self):
+        return self.getOrDefault(self.inTrainingCheckpointsDir)
+
+    def getInTrainingCheckpointsTreeInterval(self):
+        return self.getOrDefault(self.inTrainingCheckpointsTreeInterval)
+
     def getModelId(self):
         return self.getOrDefault(self.modelId)
 
@@ -519,6 +555,9 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
     def setPredNoiseBandwidth(self, value):
         return self._set(predNoiseBandwidth=value)
 
+    def setInteractionConstraints(self, value):
+        return self._set(interactionConstraints=value)
+
     def setBalanceClasses(self, value):
         return self._set(balanceClasses=value)
 
@@ -576,9 +615,18 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
     def setCalibrateModel(self, value):
         return self._set(calibrateModel=value)
 
+    def setCalibrationMethod(self, value):
+        return self._set(calibrationMethod=value)
+
     def setCheckConstantResponse(self, value):
         return self._set(checkConstantResponse=value)
 
+    def setInTrainingCheckpointsDir(self, value):
+        return self._set(inTrainingCheckpointsDir=value)
+
+    def setInTrainingCheckpointsTreeInterval(self, value):
+        return self._set(inTrainingCheckpointsTreeInterval=value)
+
     def setModelId(self, value):
         return self._set(modelId=value)
 
